@@ -1,5 +1,4 @@
 use actix_web::{web, HttpRequest, HttpResponse, Responder};
-use log;
 use reqwest::Client;
 
 use crate::{api, error, fetch, format, io, statics, utils};
@@ -23,22 +22,16 @@ pub async fn get(
     match file_content {
         Ok(value) => Ok(HttpResponse::Ok().body(value)),
         Err(_) => {
-            log::debug!(
-                "File not found! For api: {}, resource: {}",
-                &api,
-                format::filename(&resource),
-            );
-
             statics::ENVS.allow_externals_calls()?;
+
             let url = format::url(&api, &qs);
-
-            log::debug!("External get to: {}", url);
-
             let res = fetch::get(&client, &url)
                 .await
                 .unwrap_or(serde_json::json!({}));
             let file_content = serde_json::to_string(&res).unwrap_or("".to_string());
+
             io::write(&resource, file_content)?;
+
             Ok(HttpResponse::Created().json(res))
         }
     }
@@ -63,23 +56,16 @@ pub async fn post(
     match file_content {
         Ok(value) => Ok(HttpResponse::Ok().body(value)),
         Err(_) => {
-            log::debug!(
-                "File not found! For api: {}, resource: {}, payload_post: {}",
-                &api,
-                format::filename(&resource),
-                &payload,
-            );
-
             statics::ENVS.allow_externals_calls()?;
+
             let url = format::url(&api, &qs);
-
-            log::debug!("External post to: {}", url);
-
             let res = fetch::post(&client, &url, &payload)
                 .await
                 .unwrap_or(serde_json::json!({}));
             let file_content = serde_json::to_string(&res).unwrap_or("".to_string());
+
             io::write(&resource, file_content)?;
+
             Ok(HttpResponse::Created().json(res))
         }
     }
