@@ -1,12 +1,10 @@
 use std::{fs, path::Path};
 
-use log;
-
 use crate::{format, statics};
 
 pub fn mock_dir() -> std::io::Result<()> {
     if !Path::new(&statics::ENVS.mock_dir).exists() {
-        fs::create_dir(&statics::ENVS.mock_dir)?;
+        fs::create_dir_all(&statics::ENVS.mock_dir)?;
     }
     Ok(())
 }
@@ -19,7 +17,5 @@ pub fn read(resource: &str) -> Result<String, std::io::Error> {
 
 pub fn write(resource: &str, file_content: String) -> Result<(), std::io::Error> {
     let filename = format::filename(resource);
-
-    log::debug!("Write filename: {}", filename);
     Ok(fs::write(filename, file_content)?)
 }
